@@ -3,7 +3,7 @@ from unittest.mock import Mock, patch
 
 import pytest
 
-from streamlink.plugin.plugin import BIT_RATE_WEIGHT_RATIO, LOW_PRIORITY, NORMAL_PRIORITY, NO_PRIORITY
+from streamlink.plugin.plugin import BIT_RATE_WEIGHT_RATIO, LOW_PRIORITY, NO_PRIORITY, NORMAL_PRIORITY
 from streamlink.plugins.dash import MPEGDASH
 from tests.plugins import PluginCanHandleUrl
 
@@ -21,7 +21,7 @@ class TestPluginCanHandleUrlMPEGDASH(PluginCanHandleUrl):
     ]
 
 
-@pytest.mark.parametrize("url,priority", [
+@pytest.mark.parametrize(("url", "priority"), [
     ("http://example.com/foo.mpd", LOW_PRIORITY),
     ("dash://http://example.com/foo.mpd", NORMAL_PRIORITY),
     ("dash://http://example.com/bar", NORMAL_PRIORITY),
@@ -31,7 +31,7 @@ def test_priority(url, priority):
     assert next((matcher.priority for matcher in MPEGDASH.matchers if matcher.pattern.match(url)), NO_PRIORITY) == priority
 
 
-@pytest.mark.parametrize("url,expected", [
+@pytest.mark.parametrize(("url", "expected"), [
     ("example.com/foo.mpd", "https://example.com/foo.mpd"),
     ("http://example.com/foo.mpd", "http://example.com/foo.mpd"),
     ("https://example.com/foo.mpd", "https://example.com/foo.mpd"),
@@ -49,8 +49,8 @@ def test_get_streams(parse_manifest, url, expected):
 
 class TestPluginMPEGDASH(unittest.TestCase):
     def test_stream_weight(self):
-        self.assertAlmostEqual(MPEGDASH.stream_weight("720p"), (720, 'pixels'))
-        self.assertAlmostEqual(MPEGDASH.stream_weight("1080p"), (1080, 'pixels'))
-        self.assertAlmostEqual(MPEGDASH.stream_weight("720p+a128k"), (720 + 128, 'pixels'))
-        self.assertAlmostEqual(MPEGDASH.stream_weight("720p+a0k"), (720, 'pixels'))
-        self.assertAlmostEqual(MPEGDASH.stream_weight("a128k"), (128 / BIT_RATE_WEIGHT_RATIO, 'bitrate'))
+        assert MPEGDASH.stream_weight("720p") == pytest.approx((720, "pixels"))
+        assert MPEGDASH.stream_weight("1080p") == pytest.approx((1080, "pixels"))
+        assert MPEGDASH.stream_weight("720p+a128k") == pytest.approx((720 + 128, "pixels"))
+        assert MPEGDASH.stream_weight("720p+a0k") == pytest.approx((720, "pixels"))
+        assert MPEGDASH.stream_weight("a128k") == pytest.approx((128 / BIT_RATE_WEIGHT_RATIO, "bitrate"))
