@@ -7,7 +7,7 @@ class TestPluginCanHandleUrlVlive(PluginCanHandleUrl):
 
     should_match = [
         "https://www.vlive.tv/video/156824",
-        "https://www.vlive.tv/post/0-19740901"
+        "https://www.vlive.tv/post/0-19740901",
     ]
 
     should_not_match = [
