@@ -8,11 +8,13 @@ from unittest.mock import Mock, call, patch
 import pytest
 import requests_mock
 import urllib3
+from requests.adapters import HTTPAdapter
 
 import tests.plugin
-from streamlink import NoPluginError, Streamlink
-from streamlink.exceptions import StreamlinkDeprecationWarning
-from streamlink.plugin import HIGH_PRIORITY, LOW_PRIORITY, NORMAL_PRIORITY, NO_PRIORITY, Plugin, pluginmatcher
+from streamlink.exceptions import NoPluginError, StreamlinkDeprecationWarning
+from streamlink.plugin import HIGH_PRIORITY, LOW_PRIORITY, NO_PRIORITY, NORMAL_PRIORITY, Plugin, pluginmatcher
+from streamlink.plugin.api.http_session import TLSNoDHAdapter
+from streamlink.session import Streamlink
 from streamlink.stream.hls import HLSStream
 from streamlink.stream.http import HTTPStream
 
@@ -23,12 +25,6 @@ PATH_TESTPLUGINS_OVERRIDE = PATH_TESTPLUGINS / "override"
 _original_allowed_gai_family = urllib3.util.connection.allowed_gai_family  # type: ignore[attr-defined]
 
 
-@pytest.fixture
-def session():
-    with patch("streamlink.session.Streamlink.load_builtin_plugins"):
-        yield Streamlink()
-
-
 class EmptyPlugin(Plugin):
     def _get_streams(self):
         pass  # pragma: no cover
@@ -173,25 +169,25 @@ class TestSession(unittest.TestCase):
 
     def test_resolve_url_priority(self):
         @pluginmatcher(priority=HIGH_PRIORITY, pattern=re.compile(
-            "https://(high|normal|low|no)$"
+            "https://(high|normal|low|no)$",
         ))
         class HighPriority(EmptyPlugin):
             pass
 
         @pluginmatcher(priority=NORMAL_PRIORITY, pattern=re.compile(
-            "https://(normal|low|no)$"
+            "https://(normal|low|no)$",
         ))
         class NormalPriority(EmptyPlugin):
             pass
 
         @pluginmatcher(priority=LOW_PRIORITY, pattern=re.compile(
-            "https://(low|no)$"
+            "https://(low|no)$",
         ))
         class LowPriority(EmptyPlugin):
             pass
 
         @pluginmatcher(priority=NO_PRIORITY, pattern=re.compile(
-            "https://(no)$"
+            "https://(no)$",
         ))
         class NoPriority(EmptyPlugin):
             pass
@@ -222,7 +218,7 @@ class TestSession(unittest.TestCase):
 
     def test_resolve_deprecated(self):
         @pluginmatcher(priority=LOW_PRIORITY, pattern=re.compile(
-            "https://low"
+            "https://low",
         ))
         class LowPriority(EmptyPlugin):
             pass
@@ -260,14 +256,14 @@ class TestSession(unittest.TestCase):
     def test_options(self):
         session = self.subject()
         session.set_option("test_option", "option")
-        self.assertEqual(session.get_option("test_option"), "option")
-        self.assertEqual(session.get_option("non_existing"), None)
+        assert session.get_option("test_option") == "option"
+        assert session.get_option("non_existing") is None
 
-        self.assertEqual(session.get_plugin_option("testplugin", "a_option"), "default")
+        assert session.get_plugin_option("testplugin", "a_option") == "default"
         session.set_plugin_option("testplugin", "another_option", "test")
-        self.assertEqual(session.get_plugin_option("testplugin", "another_option"), "test")
-        self.assertEqual(session.get_plugin_option("non_existing", "non_existing"), None)
-        self.assertEqual(session.get_plugin_option("testplugin", "non_existing"), None)
+        assert session.get_plugin_option("testplugin", "another_option") == "test"
+        assert session.get_plugin_option("non_existing", "non_existing") is None
+        assert session.get_plugin_option("testplugin", "non_existing") is None
 
     def test_streams(self):
         session = self.subject()
@@ -336,9 +332,9 @@ class TestSession(unittest.TestCase):
     def test_set_and_get_locale(self):
         session = Streamlink()
         session.set_option("locale", "en_US")
-        self.assertEqual(session.localization.country.alpha2, "US")
-        self.assertEqual(session.localization.language.alpha2, "en")
-        self.assertEqual(session.localization.language_code, "en_US")
+        assert session.localization.country.alpha2 == "US"
+        assert session.localization.language.alpha2 == "en"
+        assert session.localization.language_code == "en_US"
 
     @patch("streamlink.session.HTTPSession")
     def test_interface(self, mock_httpsession):
@@ -348,22 +344,22 @@ class TestSession(unittest.TestCase):
         mock_httpsession.return_value = Mock(adapters={
             "http://": adapter_http,
             "https://": adapter_https,
-            "foo://": adapter_foo
+            "foo://": adapter_foo,
         })
         session = self.subject(load_plugins=False)
-        self.assertEqual(session.get_option("interface"), None)
+        assert session.get_option("interface") is None
 
         session.set_option("interface", "my-interface")
-        self.assertEqual(adapter_http.poolmanager.connection_pool_kw, {"source_address": ("my-interface", 0)})
-        self.assertEqual(adapter_https.poolmanager.connection_pool_kw, {"source_address": ("my-interface", 0)})
-        self.assertEqual(adapter_foo.poolmanager.connection_pool_kw, {})
-        self.assertEqual(session.get_option("interface"), "my-interface")
+        assert adapter_http.poolmanager.connection_pool_kw == {"source_address": ("my-interface", 0)}
+        assert adapter_https.poolmanager.connection_pool_kw == {"source_address": ("my-interface", 0)}
+        assert adapter_foo.poolmanager.connection_pool_kw == {}
+        assert session.get_option("interface") == "my-interface"
 
         session.set_option("interface", None)
-        self.assertEqual(adapter_http.poolmanager.connection_pool_kw, {})
-        self.assertEqual(adapter_https.poolmanager.connection_pool_kw, {})
-        self.assertEqual(adapter_foo.poolmanager.connection_pool_kw, {})
-        self.assertEqual(session.get_option("interface"), None)
+        assert adapter_http.poolmanager.connection_pool_kw == {}
+        assert adapter_https.poolmanager.connection_pool_kw == {}
+        assert adapter_foo.poolmanager.connection_pool_kw == {}
+        assert session.get_option("interface") is None
 
     @patch("streamlink.session.urllib3_util_connection", allowed_gai_family=_original_allowed_gai_family)
     def test_ipv4_ipv6(self, mock_urllib3_util_connection):
@@ -400,93 +396,105 @@ class TestSession(unittest.TestCase):
         assert session.get_option("ipv6") is False
         assert mock_urllib3_util_connection.allowed_gai_family is _original_allowed_gai_family
 
-    @patch("streamlink.session.urllib3_util_ssl", DEFAULT_CIPHERS="foo:!bar:baz")
-    def test_http_disable_dh(self, mock_urllib3_util_ssl):
+    def test_http_disable_dh(self):
         session = self.subject(load_plugins=False)
-        assert mock_urllib3_util_ssl.DEFAULT_CIPHERS == "foo:!bar:baz"
+        assert isinstance(session.http.adapters["https://"], HTTPAdapter)
+        assert not isinstance(session.http.adapters["https://"], TLSNoDHAdapter)
 
         session.set_option("http-disable-dh", True)
-        assert mock_urllib3_util_ssl.DEFAULT_CIPHERS == "foo:!bar:baz:!DH"
-
-        session.set_option("http-disable-dh", True)
-        assert mock_urllib3_util_ssl.DEFAULT_CIPHERS == "foo:!bar:baz:!DH"
+        assert isinstance(session.http.adapters["https://"], TLSNoDHAdapter)
 
         session.set_option("http-disable-dh", False)
-        assert mock_urllib3_util_ssl.DEFAULT_CIPHERS == "foo:!bar:baz"
+        assert isinstance(session.http.adapters["https://"], HTTPAdapter)
+        assert not isinstance(session.http.adapters["https://"], TLSNoDHAdapter)
 
 
 class TestSessionOptionHttpProxy:
-    @pytest.fixture
-    def no_deprecation(self, recwarn: pytest.WarningsRecorder):
+    @pytest.fixture()
+    def _no_deprecation(self, recwarn: pytest.WarningsRecorder):
         yield
         assert recwarn.list == []
 
-    @pytest.fixture
-    def logs_deprecation(self, recwarn: pytest.WarningsRecorder):
+    @pytest.fixture()
+    def _logs_deprecation(self, recwarn: pytest.WarningsRecorder):
         yield
-        assert [(record.category, str(record.message)) for record in recwarn.list] == [
+        assert [(record.category, str(record.message), record.filename) for record in recwarn.list] == [
             (
                 StreamlinkDeprecationWarning,
                 "The `https-proxy` option has been deprecated in favor of a single `http-proxy` option",
+                __file__,
             ),
         ]
 
-    def test_https_proxy_default(self, session: Streamlink, no_deprecation):
+    @pytest.mark.usefixtures("_no_deprecation")
+    def test_https_proxy_default(self, session: Streamlink):
         session.set_option("http-proxy", "http://testproxy.com")
 
         assert session.http.proxies["http"] == "http://testproxy.com"
         assert session.http.proxies["https"] == "http://testproxy.com"
 
-    def test_https_proxy_set_first(self, session: Streamlink, logs_deprecation):
+    @pytest.mark.usefixtures("_logs_deprecation")
+    def test_https_proxy_set_first(self, session: Streamlink):
         session.set_option("https-proxy", "https://testhttpsproxy.com")
         session.set_option("http-proxy", "http://testproxy.com")
 
         assert session.http.proxies["http"] == "http://testproxy.com"
         assert session.http.proxies["https"] == "http://testproxy.com"
 
-    def test_https_proxy_default_override(self, session: Streamlink, logs_deprecation):
+    @pytest.mark.usefixtures("_logs_deprecation")
+    def test_https_proxy_default_override(self, session: Streamlink):
         session.set_option("http-proxy", "http://testproxy.com")
         session.set_option("https-proxy", "https://testhttpsproxy.com")
 
         assert session.http.proxies["http"] == "https://testhttpsproxy.com"
         assert session.http.proxies["https"] == "https://testhttpsproxy.com"
 
-    def test_https_proxy_set_only(self, session: Streamlink, logs_deprecation):
+    @pytest.mark.usefixtures("_logs_deprecation")
+    def test_https_proxy_set_only(self, session: Streamlink):
         session.set_option("https-proxy", "https://testhttpsproxy.com")
 
         assert session.http.proxies["http"] == "https://testhttpsproxy.com"
         assert session.http.proxies["https"] == "https://testhttpsproxy.com"
 
-    def test_http_proxy_socks(self, session: Streamlink, no_deprecation):
+    @pytest.mark.usefixtures("_no_deprecation")
+    def test_http_proxy_socks(self, session: Streamlink):
         session.set_option("http-proxy", "socks5://localhost:1234")
 
         assert session.http.proxies["http"] == "socks5://localhost:1234"
         assert session.http.proxies["https"] == "socks5://localhost:1234"
 
-    def test_https_proxy_socks(self, session: Streamlink, logs_deprecation):
+    @pytest.mark.usefixtures("_logs_deprecation")
+    def test_https_proxy_socks(self, session: Streamlink):
         session.set_option("https-proxy", "socks5://localhost:1234")
 
         assert session.http.proxies["http"] == "socks5://localhost:1234"
         assert session.http.proxies["https"] == "socks5://localhost:1234"
 
-    def test_get_http_proxy(self, session: Streamlink, no_deprecation):
+    @pytest.mark.usefixtures("_no_deprecation")
+    def test_get_http_proxy(self, session: Streamlink):
         session.http.proxies["http"] = "http://testproxy1.com"
         session.http.proxies["https"] = "http://testproxy2.com"
         assert session.get_option("http-proxy") == "http://testproxy1.com"
 
-    def test_get_https_proxy(self, session: Streamlink, logs_deprecation):
+    @pytest.mark.usefixtures("_logs_deprecation")
+    def test_get_https_proxy(self, session: Streamlink):
         session.http.proxies["http"] = "http://testproxy1.com"
         session.http.proxies["https"] = "http://testproxy2.com"
         assert session.get_option("https-proxy") == "http://testproxy2.com"
 
+    @pytest.mark.usefixtures("_logs_deprecation")
+    def test_https_proxy_get_directly(self, session: Streamlink):
+        # The DeprecationWarning's origin must point to this call, even without the set_option() wrapper
+        session.options.get("https-proxy")
+
+    @pytest.mark.usefixtures("_logs_deprecation")
+    def test_https_proxy_set_directly(self, session: Streamlink):
+        # The DeprecationWarning's origin must point to this call, even without the set_option() wrapper
+        session.options.set("https-proxy", "https://foo")
+
 
-@pytest.mark.parametrize("option", [
-    pytest.param(("http-cookies", "cookies"), id="http-cookies"),
-    pytest.param(("http-headers", "headers"), id="http-headers"),
-    pytest.param(("http-query-params", "params"), id="http-query-params"),
-], indirect=True)
 class TestOptionsKeyEqualsValue:
-    @pytest.fixture
+    @pytest.fixture()
     def option(self, request, session: Streamlink):
         option, attr = request.param
         httpsessionattr = getattr(session.http, attr)
@@ -497,8 +505,65 @@ class TestOptionsKeyEqualsValue:
         assert httpsessionattr.get("foo") == "foo=bar"
         assert httpsessionattr.get("bar") == "123"
 
+    @pytest.mark.parametrize(
+        "option",
+        [
+            pytest.param(("http-cookies", "cookies"), id="http-cookies"),
+            pytest.param(("http-headers", "headers"), id="http-headers"),
+            pytest.param(("http-query-params", "params"), id="http-query-params"),
+        ],
+        indirect=["option"],
+    )
     def test_dict(self, session: Streamlink, option: str):
         session.set_option(option, {"foo": "foo=bar", "bar": "123"})
 
-    def test_string(self, session: Streamlink, option: str):
-        session.set_option(option, "foo=foo=bar;bar=123;baz")
+    @pytest.mark.parametrize(
+        ("option", "value"),
+        [
+            pytest.param(("http-cookies", "cookies"), "foo=foo=bar;bar=123;baz", id="http-cookies"),
+            pytest.param(("http-headers", "headers"), "foo=foo=bar;bar=123;baz", id="http-headers"),
+            pytest.param(("http-query-params", "params"), "foo=foo=bar&bar=123&baz", id="http-query-params"),
+        ],
+        indirect=["option"],
+    )
+    def test_string(self, session: Streamlink, option: str, value: str):
+        session.set_option(option, value)
+
+
+@pytest.mark.parametrize(
+    ("option", "attr", "default", "value"),
+    [
+        ("http-ssl-cert", "cert", None, "foo"),
+        ("http-ssl-verify", "verify", True, False),
+        ("http-trust-env", "trust_env", True, False),
+        ("http-timeout", "timeout", 20.0, 30.0),
+    ],
+)
+def test_options_http_other(session: Streamlink, option: str, attr: str, default, value):
+    httpsessionattr = getattr(session.http, attr)
+    assert httpsessionattr == default
+    assert session.get_option(option) == httpsessionattr
+
+    session.set_option(option, value)
+    assert session.get_option(option) == value
+
+
+class TestOptionsDocumentation:
+    @pytest.fixture()
+    def docstring(self, session: Streamlink):
+        docstring = session.set_option.__doc__
+        assert docstring is not None
+        return docstring
+
+    def test_default_option_is_documented(self, session: Streamlink, docstring: str):
+        assert session.options.keys()
+        for option in session.options:
+            assert f"* - {option}" in docstring, f"Option '{option}' is documented"
+
+    def test_documented_option_exists(self, session: Streamlink, docstring: str):
+        options = session.options
+        setters = options._MAP_SETTERS.keys()
+        documented = re.compile(r"\* - (\S+)").findall(docstring)[1:]
+        assert documented
+        for option in documented:
+            assert option in options or option in setters, f"Documented option '{option}' exists"
