@@ -5,6 +5,7 @@ from unittest.mock import patch
 from streamlink import Streamlink
 from streamlink.api import streams
 
+
 PluginPath = os.path.join(os.path.dirname(__file__), "plugin")
 
 
@@ -15,30 +16,30 @@ def get_session():
 
 
 class TestStreamlinkAPI(unittest.TestCase):
-    @patch('streamlink.api.Streamlink', side_effect=get_session)
+    @patch("streamlink.api.Streamlink", side_effect=get_session)
     def test_find_test_plugin(self, session):
-        self.assertIn("hls", streams("test.se"))
+        assert "hls" in streams("test.se")
 
-    @patch('streamlink.api.Streamlink', side_effect=get_session)
+    @patch("streamlink.api.Streamlink", side_effect=get_session)
     def test_no_streams_exception(self, session):
-        self.assertEqual({}, streams("test.se/NoStreamsError"))
+        assert streams("test.se/NoStreamsError") == {}
 
-    @patch('streamlink.api.Streamlink', side_effect=get_session)
+    @patch("streamlink.api.Streamlink", side_effect=get_session)
     def test_no_streams(self, session):
-        self.assertEqual({}, streams("test.se/empty"))
+        assert streams("test.se/empty") == {}
 
-    @patch('streamlink.api.Streamlink', side_effect=get_session)
+    @patch("streamlink.api.Streamlink", side_effect=get_session)
     def test_stream_type_filter(self, session):
         stream_types = ["hls"]
         available_streams = streams("test.se", stream_types=stream_types)
-        self.assertIn("hls", available_streams)
-        self.assertNotIn("test", available_streams)
-        self.assertNotIn("http", available_streams)
+        assert "hls" in available_streams
+        assert "test" not in available_streams
+        assert "http" not in available_streams
 
-    @patch('streamlink.api.Streamlink', side_effect=get_session)
+    @patch("streamlink.api.Streamlink", side_effect=get_session)
     def test_stream_type_wildcard(self, session):
         stream_types = ["hls", "*"]
         available_streams = streams("test.se", stream_types=stream_types)
-        self.assertIn("hls", available_streams)
-        self.assertIn("test", available_streams)
-        self.assertIn("http", available_streams)
+        assert "hls" in available_streams
+        assert "test" in available_streams
+        assert "http" in available_streams
